@@ -8,7 +8,7 @@ from tenancy.models import Tenant
 from dcim.models import Region
 from circuits.models import Provider
 from extras.models import Tag
-from .models import Number, Trunk, Cluster, DevicePool
+from .models import Number, Trunk, UCCluster, DevicePool
 
 
 class NumberFilterForm(BootstrapMixin, forms.Form):
@@ -252,9 +252,9 @@ class TrunkCSVForm(CSVModelForm):
 
 
 
-class ClusterFilterForm(BootstrapMixin, forms.Form):
+class UCClusterFilterForm(BootstrapMixin, forms.Form):
 
-    model = Cluster
+    model = UCCluster
     q = forms.CharField(
         required=False,
         label='Search'
@@ -269,16 +269,16 @@ class ClusterFilterForm(BootstrapMixin, forms.Form):
     tag = TagFilterField(model)
 
 
-class ClusterEditForm(BootstrapMixin, forms.ModelForm):
+class UCClusterEditForm(BootstrapMixin, forms.ModelForm):
 
-    cluster = forms.CharField(
+    UCCluster = forms.CharField(
         required=True,
         widget=forms.TextInput(
             attrs={
                 'class': 'form-control',
                 'autocomplete': 'off',
                 'pattern': r'^\+?[0-9A-D\*\#]+$',
-                'title': 'Enter the Cluster Name'
+                'title': 'Enter the UCCluster Name'
             }
         )
     )
@@ -288,14 +288,14 @@ class ClusterEditForm(BootstrapMixin, forms.ModelForm):
     )
 
     class Meta:
-        model = Cluster
-        fields = ('cluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2')
+        model = UCCluster
+        fields = ('UCCluster', 'tenant', 'description', 'publisher', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2')
 
 
-class ClusterBulkEditForm(BootstrapMixin, AddRemoveTagsForm, BulkEditForm):
+class UCClusterBulkEditForm(BootstrapMixin, AddRemoveTagsForm, BulkEditForm):
 
     pk = forms.ModelMultipleChoiceField(
-        queryset=Cluster.objects.all(),
+        queryset=UCCluster.objects.all(),
         widget=forms.MultipleHiddenInput()
     )
     tenant = DynamicModelChoiceField(
@@ -341,7 +341,7 @@ class ClusterBulkEditForm(BootstrapMixin, AddRemoveTagsForm, BulkEditForm):
         nullable_fields = ('description', 'subscriber1', 'subscriber2', 'subscriber3', 'subscriber4', 'tftp1', 'tftp2')
 
 
-class ClusterCSVForm(CSVModelForm):
+class UCClusterCSVForm(CSVModelForm):
     tenant = CSVModelChoiceField(
         queryset=Tenant.objects.all(),
         required=True,
@@ -350,8 +350,8 @@ class ClusterCSVForm(CSVModelForm):
     )
 
     class Meta:
-        model = Cluster
-        fields = Cluster.csv_headers
+        model = UCCluster
+        fields = UCCluster.csv_headers
 
 
 class DevicePoolFilterForm(BootstrapMixin, forms.Form):
